==> haskell-th-expand-syns-0.4.12.0-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-expand-syns
version:              0.4.12.0
visibility:           public
id:                   th-expand-syns-0.4.12.0-1o3y1tsZnwVLrXEGATMWTu
key:                  th-expand-syns-0.4.12.0-1o3y1tsZnwVLrXEGATMWTu
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  0bc2488fa5f4b555dcdbddeac4a76a57
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-expand-syns
hs-libraries:         HSth-expand-syns-0.4.12.0-1o3y1tsZnwVLrXEGATMWTu
depends:
    base-4.17.2.1 containers-0.6.7 syb-0.7.3-B3ujAx0b01UAjArJbq6cUd
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-expand-syns-0.4.12.0-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-expand-syns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-expand-syns
version:              0.4.12.0
visibility:           public
id:                   th-expand-syns-0.4.12.0-R5RTobgdrRDEoYUCFZcO2
key:                  th-expand-syns-0.4.12.0-R5RTobgdrRDEoYUCFZcO2
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  9cdc926f5cba96533b68d445f35359df
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-expand-syns-0.4.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-expand-syns
hs-libraries:         HSth-expand-syns-0.4.12.0-R5RTobgdrRDEoYUCFZcO2
depends:
    base-4.17.2.1 containers-0.6.7 syb-0.7.3-8wamvTeFqIS3IMzaHn3GXS
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
